@@ -2,6 +2,9 @@ use MooseX::Declare;
 
 class TSQL::AST::SQLVariableDeclaration extends TSQL::AST::SQLFragment {
 
+use TSQL::AST::SQLIdentifier;
+use TSQL::AST::SQLDataType;
+
 has 'variableName' => (
       is  => 'rw',
       isa => 'TSQL::AST::SQLIdentifier',
